package com.app.dto.wx;


import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;

/**
 * 功能描述：
 * 小程序调起支付API
 *
 * 官方文档
 * https://pay.weixin.qq.com/wiki/doc/api/wxa/wxa_api.php?chapter=7_7&index=5
 */
@ApiModel("微信[预支付]Dto")
@Data
@NoArgsConstructor
@AllArgsConstructor
@Accessors(chain = true)
public class PrePayDto {

    /**
     * 时间戳
     * 时间戳从1970年1月1日00:00:00至今的秒数,即当前的时间
     */
    @ApiModelProperty("时间戳")
    private String timeStamp;

    /**
     * 随机串
     * 随机字符串，不长于32位。推荐随机数生成算法
     */
    @ApiModelProperty("随机串")
    private String nonceStr;

    /**
     * 数据包
     * 统一下单接口返回的 prepay_id 参数值
     * add by 梁展鹏 20190820 这里非常坑爹官方竟然用package作为变量，再次落实微信(腾讯系)非Java主流...
     * https://pay.weixin.qq.com/wiki/doc/api/wxa/wxa_api.php?chapter=7_7&index=5
     */
    @ApiModelProperty("数据包")
    private String packages;

    /**
     * 签名方式
     * 签名类型，默认为MD5，支持HMAC-SHA256和MD5。注意此处需与统一下单的签名类型一致
     */
    @ApiModelProperty("签名方式")
    private String signType;

    /**
     * 签名值
     */
    @ApiModelProperty("签名值")
    private String paySign;

}
