package com.app.dto.wx;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;

/**
 * 功能描述：微信账号
 * UserInfo(用户信息)
 * https://developers.weixin.qq.com/miniprogram/dev/api/open-api/user-info/UserInfo.html
 *
 * @Auther: 梁展鹏
 * @Date: 2018/7/17 14:03
 */
@ApiModel("微信用户信息Dto")
@Data
@NoArgsConstructor
@AllArgsConstructor
@Accessors(chain = true)
public class WxUserInfoDto {

    @ApiModelProperty("openId")
    private String openId;

    @ApiModelProperty("unionId")
    private String unionId;

    @ApiModelProperty("用户昵称")
    private String nickName;

    /**
     * URL 最后一个数值代表正方形头像大小（有 0、46、64、96、132 数值可选，
     * 0 代表 640x640 的正方形头像，
     * 46 表示 46x46 的正方形头像，剩余数值以此类推。默认132），
     * 用户没有头像时该项为空。若用户更换头像，原有头像 URL 将失效。
     */
    @ApiModelProperty("用户头像图片的 URL")
    private String avatarUrl;

    @ApiModelProperty("用户性别（0：未知、1：男性、2：女性）")
    private Integer gender;

    @ApiModelProperty("用户所在国家")
    private String country;

    @ApiModelProperty("用户所在省份")
    private String province;

    @ApiModelProperty("用户所在城市")
    private String city;

    /**
     * 显示 country，province，city 所用的语言
     * en	英文
     * zh_CN	简体中文
     * zh_TW	繁体中文
     */
    @ApiModelProperty("语言")
    private String language;

}
